# Generated by Django 2.2.14 on 2021-05-29 09:05

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('carousels', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='carousel',
            name='settings',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict, help_text="For example: \n        {\n            items: 1,\n            loop: true,\n            dots: false,\n            nav: true,\n            responsiveClass: true,\n            animateOut: 'fadeOut',\n            autoplay: true,\n            autoplayHoverPause: true,\n            autoplayTimeout: 5000,\n            smartSpeed: 1000,\n            fluidSpeed: 1000,\n            autoplaySpeed: 1000,\n            slideTransition: 'linear',\n            center: true,\n            responsive: {\n                0: {\n                    items: 1,\n                },\n                576: {\n                    items: 2,\n                },\n                768: {\n                    items: 2.5,\n                },\n                992: {\n                    items: 3,\n                },\n                1200: {\n                    items: 4.75,\n                }\n            }\n        }\n    ", verbose_name='settings'),
        ),
    ]



from django.contrib.staticfiles.templatetags.staticfiles import register
from django.core.exceptions import ObjectDoesNotExist

from carousels.models import Carousel


@register.inclusion_tag('carousels/carousel.html')
def carousel(slug):
    data = {'slug': slug}

    try:
        data['carousel'] = Carousel.objects.get(slug=slug)
    except ObjectDoesNotExist:
        pass

    return data




import json

from django.contrib.postgres.fields import JSONField
from django.db import models
from django.utils.translation import ugettext_lazy as _, pgettext_lazy


class Carousel(models.Model):
    example_settings = """
        {
            items: 1,
            loop: true,
            dots: false,
            nav: true,
            responsiveClass: true,
            animateOut: 'fadeOut',
            autoplay: true,
            autoplayHoverPause: true,
            autoplayTimeout: 5000,
            smartSpeed: 1000,
            fluidSpeed: 1000,
            autoplaySpeed: 1000,
            slideTransition: 'linear',
            center: true,
            responsive: {
                0: {
                    items: 1,
                },
                576: {
                    items: 2,
                },
                768: {
                    items: 2.5,
                },
                992: {
                    items: 3,
                },
                1200: {
                    items: 4.75,
                }
            }
        }
    """
    slug = models.SlugField(verbose_name=_('identifier'), help_text=_('slug'), unique=True, max_length=20)
    settings = JSONField(verbose_name=_('settings'), blank=True, default=dict,
                         help_text=_("For example: %s") % example_settings)

    def __str__(self):
        return self.slug

    class Meta:
        verbose_name = _('carousel')
        verbose_name_plural = _('carousels')

    @property
    def settings_as_json(self):
        return json.dumps(self.settings)


class Slide(models.Model):
    carousel = models.ForeignKey(to=Carousel, verbose_name=_('carousel'), on_delete=models.CASCADE)
    position = models.PositiveSmallIntegerField(pgettext_lazy('sequence/order', 'position'), default=0)
    title = models.CharField(_('title'), max_length=100, blank=True)
    text = models.TextField(_('text'), blank=True)
    button = models.CharField(_('button'), help_text=_('label'), max_length=30, blank=True)
    url = models.CharField(_('URL'), help_text='CTA', max_length=100, blank=True)
    # background = models.CharField(_('background'), max_length=100, help_text=_('URL to image'))
    background = models.ImageField(_('background'), blank=True, null=True, default=None, upload_to='slides')
    # TODO: i18n

    class Meta:
        verbose_name = _(u'slide')
        verbose_name_plural = _(u'slides')
        ordering = ('position', )

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return "#"



# Generated by Django 2.2.14 on 2021-05-23 12:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Carousel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(help_text='slug', max_length=20, unique=True, verbose_name='identifier')),
            ],
            options={
                'verbose_name': 'carousel',
                'verbose_name_plural': 'carousels',
            },
        ),
        migrations.CreateModel(
            name='Slide',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('position', models.PositiveSmallIntegerField(default=0, verbose_name='position')),
                ('title', models.CharField(blank=True, max_length=100, verbose_name='title')),
                ('text', models.TextField(blank=True, verbose_name='text')),
                ('button', models.CharField(blank=True, help_text='label', max_length=30, verbose_name='button')),
                ('url', models.CharField(blank=True, help_text='CTA', max_length=100, verbose_name='URL')),
                ('background', models.ImageField(blank=True, default=None, null=True, upload_to='slides', verbose_name='background')),
                ('carousel', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='carousels.Carousel', verbose_name='carousel')),
            ],
            options={
                'verbose_name': 'slide',
                'verbose_name_plural': 'slides',
                'ordering': ('position',),
            },
        ),
    ]



from django.contrib import admin

from carousels.models import Carousel, Slide


class SlideInline(admin.StackedInline):
    model = Slide
    extra = 3
    fields = ['position', 'title', 'text', 'button', 'url', 'background']


@admin.register(Carousel)
class CarouselAdmin(admin.ModelAdmin):
    search_fields = ('slug',)
    list_display = ('id', 'slug')
    list_editable = ('slug',)
    inlines = [SlideInline]


@admin.register(Slide)
class SlideAdmin(admin.ModelAdmin):
    search_fields = ('title', 'text', 'button', 'URL')
    list_display = ('id', 'title', 'carousel', 'button', 'url', 'background', 'position')
    list_display_links = ['id', 'title']
    # list_editable = ('title', 'button', 'url', 'position', 'background')
    list_filter = ['carousel']
